@@ -32,6 +32,8 @@ class DKOrder():
         return False
 
     def getFailedTests(self, test_level):
+        if test_level == "":
+            return list()
         failed_tests = list()
         testResults = self.testsFromOrderRun()
         for level in  ["Failed", "Warning", "Log"]:
